@@ -66,8 +66,6 @@ format_table <- function(x,
                          preserve_attributes = FALSE,
                          verbose = TRUE,
                          ...) {
-
-
   # sanity check
   if (is.null(x) || (is.data.frame(x) && nrow(x) == 0)) {
     if (isTRUE(verbose)) {
@@ -201,9 +199,6 @@ format_table <- function(x,
 }
 
 
-#' @rdname format_table
-#' @export
-parameters_table <- format_table
 
 
 
