@@ -65,7 +65,6 @@
 #' @examples
 #' # Datagrids of variables and dataframes =====================================
 #' if (require("bayestestR", quietly = TRUE) & require("datawizard", quietly = TRUE)) {
-#'
 #'   # Single variable is of interest; all others are "fixed" ------------------
 #'   # Factors
 #'   get_datagrid(iris, at = "Species") # Returns all the levels
@@ -138,23 +137,24 @@ get_datagrid.data.frame <- function(x,
                                     length = 10,
                                     range = "range",
                                     ...) {
-  target <- at
-
   # find numerics that were coerced to factor in-formula
   numeric_factors <- colnames(x)[sapply(x, function(i) isTRUE(attributes(i)$factor))]
 
   specs <- NULL
 
-  if (is.null(target)) {
+  if (is.null(at)) {
     targets <- data.frame()
   } else {
-    # Valid target argument
-    if (all(target == "all")) {
-      target <- names(x)
+    # check for interactions in "at"
+    at <- .extract_at_interactions(at)
+
+    # Valid at argument
+    if (all(at == "all")) {
+      at <- colnames(x)
     }
 
-    if (is.numeric(target) || is.logical(target)) {
-      target <- names(x)[target]
+    if (is.numeric(at) || is.logical(at)) {
+      at <- colnames(x)[at]
     }
 
     # Deal with factor in-formula transformations ============================
@@ -167,12 +167,21 @@ get_datagrid.data.frame <- function(x,
       }
     })
 
+    # Deal with logical in-formula transformations ============================
+
+    x[] <- lapply(x, function(i) {
+      if (isTRUE(attributes(i)$logical)) {
+        as.logical(i)
+      } else {
+        i
+      }
+    })
+
     # Deal with targets ==========================================================
 
-    if (is.character(target)) {
-
+    if (is.character(at)) {
       # Find eventual user-defined specifications for each target
-      specs <- do.call(rbind, lapply(target, .get_datagrid_clean_target, x = x))
+      specs <- do.call(rbind, lapply(at, .get_datagrid_clean_target, x = x))
       specs$varname <- as.character(specs$varname) # make sure it's a string not fac
       specs <- specs[!duplicated(specs$varname), ] # Drop duplicates
 
@@ -181,7 +190,7 @@ get_datagrid.data.frame <- function(x,
       # Create target list of factors -----------------------------------------
       facs <- list()
       for (fac in specs[specs$is_factor == TRUE, "varname"]) {
-        facs[[fac]] <- get_datagrid(x[[fac]], target = specs[specs$varname == fac, "expression"])
+        facs[[fac]] <- get_datagrid(x[[fac]], at = specs[specs$varname == fac, "expression"])
       }
 
       # Create target list of numerics ----------------------------------------
@@ -192,19 +201,19 @@ get_datagrid.data.frame <- function(x,
         if (length(length) == 1) {
           length <- rep(length, length(numvars))
         } else if (length(length) != length(numvars)) {
-          stop("The number of elements in `length` must match the number of numeric target variables (n = ", length(numvars), ").")
+          stop(format_message("The number of elements in `length` must match the number of numeric target variables (n = ", length(numvars), ")."), call. = FALSE)
         }
         # Sanitize 'range' argument
         if (length(range) == 1) {
           range <- rep(range, length(numvars))
         } else if (length(range) != length(numvars)) {
-          stop("The number of elements in `range` must match the number of numeric target variables (n = ", length(numvars), ").")
+          stop(format_message("The number of elements in `range` must match the number of numeric target variables (n = ", length(numvars), ")."), call. = FALSE)
         }
         # Get datagrids
         for (i in 1:length(numvars)) {
           num <- numvars[i]
           nums[[num]] <- get_datagrid(x[[num]],
-            target = specs[specs$varname == num, "expression"],
+            at = specs[specs$varname == num, "expression"],
             reference = reference[[num]],
             length = length[i],
             range = range[i],
@@ -212,11 +221,10 @@ get_datagrid.data.frame <- function(x,
           )
         }
       }
-    } else if (is.list(target)) {
-
+    } else if (is.list(at)) {
       # we have a list as at-values
-      facs <- target[sapply(x[names(target)], is.factor)]
-      nums <- target[sapply(x[names(target)], is.numeric)]
+      facs <- at[sapply(x[names(at)], is.factor)]
+      nums <- at[sapply(x[names(at)], is.numeric)]
     }
 
     # Assemble the two - the goal is to have two named lists, where variable
@@ -226,7 +234,6 @@ get_datagrid.data.frame <- function(x,
 
     # Preserve range ---------------------------------------------------------
     if (preserve_range == TRUE && length(facs) > 0 && length(nums) > 0) {
-
       # Loop through the combinations of factors
       facs_combinations <- expand.grid(facs)
       for (i in 1:nrow(facs_combinations)) {
@@ -254,7 +261,7 @@ get_datagrid.data.frame <- function(x,
       }
 
       if (nrow(targets) == 0) {
-        stop("No data left was left after range preservation. Try increasing `length` or setting `preserve_range` to FALSE.")
+        stop(format_message("No data left was left after range preservation. Try increasing `length` or setting `preserve_range` to FALSE."), call. = FALSE)
       }
     }
   }
@@ -267,7 +274,7 @@ get_datagrid.data.frame <- function(x,
     rest_df <- lapply(x[rest_vars], .get_datagrid_summary, numerics = numerics, factors = factors, ...)
     rest_df <- expand.grid(rest_df, stringsAsFactors = FALSE)
     if (nrow(targets) == 0) {
-      targets <- rest_df # If target = NULL
+      targets <- rest_df # If at = NULL
     } else {
       targets <- merge(targets, rest_df, sort = FALSE)
     }
@@ -288,7 +295,7 @@ get_datagrid.data.frame <- function(x,
   # Attributes
   attr(targets, "adjusted_for") <- ifelse(length(rest_vars) >= 1, rest_vars, NA)
   attr(targets, "at_specs") <- specs
-  attr(targets, "at") <- target
+  attr(targets, "at") <- at
   attr(targets, "preserve_range") <- preserve_range
   attr(targets, "reference") <- reference
   attr(targets, "data") <- x
@@ -342,11 +349,9 @@ get_datagrid.data.frame <- function(x,
       } else if (is.character(x) || is.logical(x)) {
         out <- unique(x)[1]
       } else {
-        stop(paste0(
-          "Argument is not numeric nor factor but ",
-          class(x),
-          ". Please report the bug at https://github.com/easystats/insight/issues"
-        ))
+        stop(format_message(paste0("Argument is not numeric nor factor but ", class(x), ".",
+        "Please report the bug at https://github.com/easystats/insight/issues"
+        )), call. = FALSE)
       }
     }
   }
@@ -369,7 +374,6 @@ get_datagrid.data.frame <- function(x,
 #' @rdname get_datagrid
 #' @export
 get_datagrid.numeric <- function(x, length = 10, range = "range", ...) {
-
   # Check and clean the target argument
   specs <- .get_datagrid_clean_target(x, ...)
 
@@ -458,12 +462,10 @@ get_datagrid.double <- get_datagrid.numeric
 #' @rdname get_datagrid
 #' @export
 get_datagrid.factor <- function(x, ...) {
-
   # Check and clean the target argument
   specs <- .get_datagrid_clean_target(x, ...)
 
   if (is.na(specs$expression)) {
-
     # Keep only unique levels
     if (is.factor(x)) {
       out <- factor(levels(droplevels(x)), levels = levels(droplevels(x)))
@@ -489,39 +491,38 @@ get_datagrid.logical <- get_datagrid.character
 # Utilities -----------------------------------------------------------------
 
 #' @keywords internal
-.get_datagrid_clean_target <- function(x, target = NULL, ...) {
+.get_datagrid_clean_target <- function(x, at = NULL, ...) {
   expression <- NA
   varname <- NA
-  original_target <- target
+  original_target <- at
 
-  if (!is.null(target)) {
-    if (is.data.frame(x) && target %in% names(x)) {
-      return(data.frame(varname = target, expression = NA))
+  if (!is.null(at)) {
+    if (is.data.frame(x) && at %in% names(x)) {
+      return(data.frame(varname = at, expression = NA))
     }
 
     # If there is an equal sign
-    if (grepl("length.out =", target)) {
-      expression <- target # This is an edgecase
-    } else if (grepl("=", target)) {
-      parts <- trim_ws(unlist(strsplit(target, "=", fixed = TRUE))) # Split and clean
+    if (grepl("length.out =", at)) {
+      expression <- at # This is an edgecase
+    } else if (grepl("=", at)) {
+      parts <- trim_ws(unlist(strsplit(at, "=", fixed = TRUE))) # Split and clean
       varname <- parts[1] # left-hand part is probably the name of the variable
-      target <- parts[2] # right-hand part is the real target
+      at <- parts[2] # right-hand part is the real target
     }
 
     if (is.na(expression) && is.data.frame(x)) {
       if (!is.na(varname)) {
         x <- x[[varname]]
       } else {
-        stop("Couldn't find which variable were selected in `target`. Check spelling and specification.")
+        stop(format_message("Couldn't find which variable were selected in `at`. Check spelling and specification."), call. = FALSE)
       }
     }
 
     # If brackets are detected [a, b]
-    if (is.na(expression) && grepl("\\[.*\\]", target)) {
-
+    if (is.na(expression) && grepl("\\[.*\\]", at)) {
       # Clean --------------------
       # Keep the content
-      parts <- trim_ws(unlist(regmatches(target, gregexpr("\\[.+?\\]", target))))
+      parts <- trim_ws(unlist(regmatches(at, gregexpr("\\[.+?\\]", at))))
       # Drop the brackets
       parts <- gsub("\\[|\\]", "", parts)
       # Split by a separator like ','
@@ -531,12 +532,14 @@ get_datagrid.logical <- get_datagrid.character
       if (all(grepl('\\".*\\"', parts))) parts <- gsub('"', "", parts, fixed = TRUE)
 
       # Make expression ----------
-      if (is.factor(x) || is.character(x)) { # Factor
+      if (is.factor(x) || is.character(x)) {
+        # Factor
         # Add quotes around them
         parts <- paste0("'", parts, "'")
         # Convert to character
         expression <- paste0("as.factor(c(", paste0(parts, collapse = ", "), "))")
-      } else { # Numeric
+      } else {
+        # Numeric
         # If only two, it's probably the range
         if (length(parts) == 2) {
           expression <- paste0("seq(", parts[1], ", ", parts[2], ", length.out = length)")
@@ -545,22 +548,22 @@ get_datagrid.logical <- get_datagrid.character
           parts <- as.numeric(parts)
           expression <- paste0("c(", paste0(parts, collapse = ", "), ")")
         } else {
-          stop(paste0("The `target` argument (", target, ") should indicate the min and the max."))
+          stop(format_message(paste0("The `at` argument (", at, ") should indicate the minimum and the maximum.")), call. = FALSE)
         }
       }
       # Else, try to directly eval the content
     } else {
-      expression <- target
+      expression <- at
       # Try to eval and make sure it works
       tryCatch(
         {
           # This is just to make sure that an expression with `length` in
           # it doesn't fail because of this undefined var
           length <- 10
-          eval(parse(text = target))
+          eval(parse(text = at))
         },
         error = function(r) {
-          stop(paste0("The `target` argument (`", original_target, "`) cannot be read and could be mispecified."))
+          stop(format_message(paste0("The `at` argument (`", original_target, "`) cannot be read and could be mispecified.")), call. = FALSE)
         }
       )
     }
@@ -588,34 +591,26 @@ get_datagrid.default <- function(x,
                                  include_response = FALSE,
                                  data = NULL,
                                  ...) {
+  # sanity check
+  if (!is_model(x)) {
+    stop("`x` must be a statistical model.", call. = FALSE)
+  }
+
   # Retrieve data from model
-  if (is.null(data)) {
-    data <- tryCatch(get_data(x)[find_variables(x, "all", flatten = TRUE)], error = function(e) NULL)
-  }
-
-  # For models with transformed parameters, "find_variables" may not return
-  # matching column names - then try retrieving terms instead
-  if (is.null(data)) {
-    data <- tryCatch(get_data(x)[find_terms(x, "all", flatten = TRUE)], error = function(e) NULL)
-  }
-
-  # still found no data - stop here
-  if (is.null(data)) {
-    stop(format_message(
-      "Can't access data that was used to fit the model in order to create the reference grid.",
-      "Please use the `data` argument."
-    ))
-  }
+  data <- .get_model_data_for_grid(x, data)
 
   # Deal with intercept-only models
   response <- find_response(x)
   if (include_response == FALSE) {
-    data <- data[!names(data) %in% response]
+    data <- data[!colnames(data) %in% response]
     if (ncol(data) < 1) {
       stop(format_message("Model only seems to be an intercept-only model. Use `include_response=TRUE` to create the reference grid."), call. = FALSE)
     }
   }
 
+  # check for interactions in "at"
+  at <- .extract_at_interactions(at)
+
   # Drop random factors
   random_factors <- find_random(x, flatten = TRUE)
   if (isFALSE(include_random) && !is.null(random_factors)) {
@@ -625,15 +620,15 @@ get_datagrid.default <- function(x,
         keep <- c(keep, at[at %in% random_factors])
         random_factors <- setdiff(random_factors, at)
       }
-      data <- data[names(data) %in% keep]
+      data <- data[colnames(data) %in% keep]
     }
   }
 
-  if (all(at == "all")) at <- names(data)
-  if (include_smooth == FALSE || include_smooth == "fixed") {
+  if (all(at == "all")) at <- colnames(data)
+  if (isFALSE(include_smooth) || identical(include_smooth, "fixed")) {
     s <- find_smooth(x, flatten = TRUE)
     if (!is.null(s)) {
-      at <- names(data)[!names(data) %in% clean_names(s)]
+      at <- colnames(data)[!colnames(data) %in% clean_names(s)]
     }
   }
 
@@ -657,8 +652,8 @@ get_datagrid.default <- function(x,
     }
   }
 
-  if (include_smooth == FALSE) {
-    vm[names(vm) %in% clean_names(find_smooth(x, flatten = TRUE))] <- NULL
+  if (isFALSE(include_smooth)) {
+    vm[colnames(vm) %in% clean_names(find_smooth(x, flatten = TRUE))] <- NULL
   }
 
   attr(vm, "model") <- x
@@ -680,23 +675,7 @@ get_datagrid.wbm <- function(x,
                              data = NULL,
                              ...) {
   # Retrieve data from model
-  if (is.null(data)) {
-    data <- tryCatch(get_data(x)[find_variables(x, "all", flatten = TRUE)], error = function(e) NULL)
-  }
-
-  # For models with transformed parameters, "find_variables" may not return
-  # matching column names - then try retrieving terms instead
-  if (is.null(data)) {
-    data <- tryCatch(get_data(x)[find_terms(x, "all", flatten = TRUE)], error = function(e) NULL)
-  }
-
-  # still found no data - stop here
-  if (is.null(data)) {
-    stop(format_message(
-      "Can't access data that was used to fit the model in order to create the reference grid.",
-      "Please use the `data` argument."
-    ))
-  }
+  data <- .get_model_data_for_grid(x, data)
 
   # add id and time variables
   data[[x@call_info$id]] <- levels(stats::model.frame(x)[[x@call_info$id]])[1]
@@ -758,3 +737,40 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
   }
   .to_numeric(row.names(x)[idx])
 }
+
+
+.get_model_data_for_grid <- function(x, data) {
+  # Retrieve data, based on variable names
+  if (is.null(data)) {
+    data <- tryCatch(get_data(x)[find_variables(x, "all", flatten = TRUE)], error = function(e) NULL)
+  }
+
+  # For models with transformed parameters, "find_variables" may not return
+  # matching column names - then try retrieving terms instead
+  if (is.null(data)) {
+    data <- tryCatch(get_data(x)[find_terms(x, "all", flatten = TRUE)], error = function(e) NULL)
+  }
+
+  # still found no data - stop here
+  if (is.null(data)) {
+    stop(format_message(
+      "Can't access data that was used to fit the model in order to create the reference grid.",
+      "Please use the `data` argument."
+    ))
+  }
+
+  data
+}
+
+
+
+.extract_at_interactions <- function(at) {
+  interaction_terms <- grepl("(:|\\*)", at)
+  if (any(interaction_terms)) {
+    at <- unique(clean_names(trim_ws(compact_character(c(
+      at[!interaction_terms],
+      unlist(strsplit(at[interaction_terms], "(:|\\*)"))
+    )))))
+  }
+  at
+}
