@@ -6,14 +6,12 @@
 get_predicted.lmerMod <- function(x,
                                   data = NULL,
                                   predict = "expectation",
-                                  ci = 0.95,
+                                  ci = NULL,
                                   ci_method = NULL,
                                   include_random = "default",
                                   iterations = NULL,
                                   verbose = TRUE,
                                   ...) {
-
-
   # Sanitize input
   args <- .get_predicted_args(
     x,
@@ -61,9 +59,11 @@ get_predicted.lmerMod <- function(x,
   }
 
   # 2. step: confidence intervals
-  ci_data <- get_predicted_ci(x, predictions,data = args$data, ci = ci,
-                              ci_method = ci_method, ci_type = args$ci_type,
-                              ...)
+  ci_data <- get_predicted_ci(x, predictions,
+    data = args$data, ci = ci,
+    ci_method = ci_method, ci_type = args$ci_type,
+    ...
+  )
 
   # 3. step: back-transform
   out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
@@ -85,7 +85,7 @@ get_predicted.merMod <- get_predicted.lmerMod
 get_predicted.glmmTMB <- function(x,
                                   data = NULL,
                                   predict = "expectation",
-                                  ci = 0.95,
+                                  ci = NULL,
                                   include_random = "default",
                                   iterations = NULL,
                                   verbose = TRUE,
@@ -126,6 +126,7 @@ get_predicted.glmmTMB <- function(x,
       type = args$type,
       re.form = args$re.form,
       unconditional = FALSE,
+      allow.new.levels = args$allow_new_levels,
       ...
     )
   }
@@ -150,7 +151,6 @@ get_predicted.glmmTMB <- function(x,
   # for predictions and CIs here.
 
   if (args$scale == "response" && args$info$is_zero_inflated) {
-
     # intermediate step: prediction from ZI model
     zi_predictions <- stats::predict(
       x,
@@ -187,7 +187,7 @@ get_predicted.glmmTMB <- function(x,
 get_predicted.MixMod <- function(x,
                                  data = NULL,
                                  predict = "expectation",
-                                 ci = 0.95,
+                                 ci = NULL,
                                  include_random = "default",
                                  iterations = NULL,
                                  verbose = TRUE,
@@ -248,17 +248,16 @@ get_predicted.MixMod <- function(x,
   # for predictions and CIs here.
 
   if (args$scale == "response" && args$info$is_zero_inflated) {
-
     # 2. and 3. step: confidence intervals and back-transform
     ci_data <- .simulate_zi_predictions(model = x, newdata = data, predictions = predictions, nsim = iterations, ci = ci)
     out <- list(predictions = predictions, ci_data = ci_data)
   } else {
-
     # 2. step: confidence intervals
     ci_data <- get_predicted_ci(
       x,
       predictions,
       data = args$data[colnames(args$data) != find_response(x)],
+      ci = ci,
       ci_type = args$ci_type,
       ...
     )
