@@ -5,12 +5,12 @@ if (.runThisTest &&
   requiet("insight") &&
   requiet("gam")) {
   data(kyphosis)
-  m1 <- gam::gam(
+  void <- capture.output(m1 <- gam::gam(
     Kyphosis ~ s(Age, 4) + Number,
     family = binomial,
     data = kyphosis,
     trace = TRUE
-  )
+  ))
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_binomial)
