@@ -1,4 +1,7 @@
-run_stan <- Sys.getenv("RunAllinsightStanTests") == "yes"
+skip_on_os(os = "mac")
+
+is_dev_version <- length(strsplit(packageDescription("insight")$Version, "\\.")[[1]]) > 3
+run_stan <- .Platform$OS.type == "unix" && is_dev_version
 
 pkgs <- c(
   "lme4",
@@ -28,19 +31,19 @@ test_that("get_predicted - lm", {
   x <- lm(mpg ~ cyl + hp, data = mtcars)
 
   # Link vs. relation
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
   expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
 
   # Relation vs. Prediction
-  rezpred <- get_predicted(x, predict = "prediction")
+  rezpred <- get_predicted(x, predict = "prediction", ci = .95)
   expect_equal(mean(abs(rezlink - rezpred)), 0, tolerance = 1e-3)
   expect_true(all(mean(summary(rezlink)$CI_high - summary(rezpred)$CI_high) < 0))
 
   # Confidence
   ref <- predict(x, se.fit = TRUE, interval = "confidence")
-  rez <- as.data.frame(get_predicted(x, predict = "expectation"))
+  rez <- as.data.frame(get_predicted(x, predict = "expectation", ci = .95))
   expect_equal(nrow(rez), 32)
   expect_equal(max(abs(as.data.frame(ref$fit)$fit - rez$Predicted)), 0, tolerance = 1e-10)
   expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-10)
@@ -48,7 +51,7 @@ test_that("get_predicted - lm", {
 
   # Prediction
   ref <- predict(x, newdata = insight::get_data(x), se.fit = TRUE, interval = "prediction")
-  rez <- as.data.frame(get_predicted(x, predict = "prediction"))
+  rez <- as.data.frame(get_predicted(x, predict = "prediction", ci = .95))
   expect_equal(nrow(rez), 32)
   expect_equal(max(abs(as.data.frame(ref$fit)$fit - rez$Predicted)), 0, tolerance = 1e-10)
   expect_equal(max(abs(as.data.frame(ref$fit)$lwr - rez$CI_low)), 0, tolerance = 1e-10)
@@ -56,7 +59,7 @@ test_that("get_predicted - lm", {
   # Bootstrap
   set.seed(333)
   ref <- predict(x, newdata = insight::get_data(x), se.fit = TRUE, interval = "confidence")
-  rez <- get_predicted(x, iterations = 600)
+  rez <- get_predicted(x, iterations = 600, ci = .95)
   expect_equal(length(rez), 32)
   expect_null(nrow(rez))
   expect_equal(mean(abs(as.data.frame(ref$fit)$fit - summary(rez)$Predicted)), 0, tolerance = 0.1)
@@ -65,12 +68,12 @@ test_that("get_predicted - lm", {
 
   # vs. Bayesian
   xbayes <- rstanarm::stan_glm(mpg ~ cyl + hp, data = mtcars, refresh = 0, seed = 333)
-  rez <- as.data.frame(get_predicted(x, predict = "link"))
-  rezbayes <- summary(get_predicted(xbayes, predict = "link"))
+  rez <- as.data.frame(get_predicted(x, predict = "link", ci = .95))
+  rezbayes <- summary(get_predicted(xbayes, predict = "link", ci = .95))
   expect_equal(mean(abs(rez$Predicted - rezbayes$Predicted)), 0, tolerance = 0.1)
   expect_equal(mean(abs(rez$CI_low - rezbayes$CI_low)), 0, tolerance = 0.1)
-  rez <- as.data.frame(get_predicted(x, predict = "prediction"))
-  rezbayes <- summary(get_predicted(xbayes, predict = "prediction"))
+  rez <- as.data.frame(get_predicted(x, predict = "prediction", ci = .95))
+  rezbayes <- summary(get_predicted(xbayes, predict = "prediction", ci = .95))
   expect_equal(mean(abs(rez$Predicted - rezbayes$Predicted)), 0, tolerance = 0.1)
   expect_equal(mean(abs(rez$CI_low - rezbayes$CI_low)), 0, tolerance = 0.2)
 })
@@ -83,22 +86,22 @@ test_that("get_predicted - glm", {
   x <- glm(vs ~ wt, data = mtcars, family = "binomial")
 
   # Link vs. relation
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
   expect_true(min(rezlink) < 0)
   expect_true(min(rezrela) > 0)
   expect_true(min(summary(rezlink)$CI_low) < 0)
   expect_true(min(summary(rezrela)$CI_low) > 0)
 
   # Relation vs. Prediction
-  rezrela <- get_predicted(x, predict = "expectation")
-  rezpred <- get_predicted(x, predict = "prediction")
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
+  rezpred <- get_predicted(x, predict = "prediction", ci = .95)
   expect_equal(mean(abs(rezrela - rezpred)), 0, tolerance = 1e-3)
   expect_true(all(mean(summary(rezrela)$CI_high - summary(rezpred)$CI_high) < 0))
 
   # Against stats::predict
-  ref <- predict(x, se.fit = TRUE, type = "response")
-  rez <- as.data.frame(get_predicted(x, predict = "expectation"))
+  ref <- predict(x, se.fit = TRUE, type = "response", ci = .95)
+  rez <- as.data.frame(get_predicted(x, predict = "expectation", ci = .95))
   expect_equal(nrow(rez), 32)
   expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-4)
   expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
@@ -106,7 +109,7 @@ test_that("get_predicted - glm", {
   expect_equal(max(abs(ref$lwr - rez$CI_low)), 0, tolerance = 1e-2)
 
   ref <- predict(x, se.fit = TRUE, type = "link")
-  rez <- as.data.frame(get_predicted(x, predict = "link"))
+  rez <- as.data.frame(get_predicted(x, predict = "link", ci = .95))
   expect_equal(nrow(rez), 32)
   expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-4)
   expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
@@ -114,17 +117,17 @@ test_that("get_predicted - glm", {
   # Bootstrap
   set.seed(333)
   ref <- suppressWarnings(predict(x, se.fit = TRUE, type = "response"))
-  rez <- suppressWarnings(summary(get_predicted(x, iterations = 800, verbose = FALSE)))
+  rez <- suppressWarnings(summary(get_predicted(x, iterations = 800, verbose = FALSE, ci = .95)))
   expect_equal(mean(abs(ref$fit - rez$Predicted)), 0, tolerance = 0.1)
 
   # vs. Bayesian
   xbayes <- rstanarm::stan_glm(vs ~ wt, data = mtcars, family = "binomial", refresh = 0, seed = 333)
-  rez <- as.data.frame(get_predicted(x, predict = "link"))
-  rezbayes <- summary(get_predicted(xbayes, predict = "link"))
+  rez <- as.data.frame(get_predicted(x, predict = "link", ci = .95))
+  rezbayes <- summary(get_predicted(xbayes, predict = "link", ci = .95))
   expect_equal(mean(abs(rez$Predicted - rezbayes$Predicted)), 0, tolerance = 0.1)
   expect_equal(mean(abs(rez$CI_low - rezbayes$CI_low)), 0, tolerance = 0.1)
-  rez <- as.data.frame(get_predicted(x, predict = "prediction"))
-  rezbayes <- summary(get_predicted(xbayes, predict = "prediction"))
+  rez <- as.data.frame(get_predicted(x, predict = "prediction", ci = .95))
+  rezbayes <- summary(get_predicted(xbayes, predict = "prediction", ci = .95))
   expect_equal(mean(abs(rez$Predicted - rezbayes$Predicted)), 0, tolerance = 0.1)
   # expect_equal(mean(abs(rez$CI_low - rezbayes$CI_low)), 0, tolerance = 0.3)
 })
@@ -146,10 +149,10 @@ test_that("get_predicted - lm (log)", {
 test_that("robust vcov", {
   requiet("sandwich")
   mod <- lm(mpg ~ hp, data = mtcars)
-  se0 <- get_predicted_se(mod)
-  se1 <- suppressWarnings(get_predicted_se(mod, vcov_estimation = "HC"))
-  se2 <- suppressWarnings(get_predicted_se(mod, vcov_estimation = "HC", vcov_type = "HC3"))
-  se3 <- get_predicted_se(mod, vcov = "HC", vcov_args = list(type = "HC3"))
+  se0 <- insight:::get_predicted_se(mod)
+  se1 <- suppressWarnings(insight:::get_predicted_se(mod, vcov_estimation = "HC"))
+  se2 <- suppressWarnings(insight:::get_predicted_se(mod, vcov_estimation = "HC", vcov_type = "HC3"))
+  se3 <- insight:::get_predicted_se(mod, vcov = "HC", vcov_args = list(type = "HC3"))
   expect_true(all(se0 != se1))
   expect_true(all(se1 == se2))
   expect_true(all(se1 == se3))
@@ -162,15 +165,15 @@ test_that("robust vcov", {
   ignore_attr = TRUE
   )
   # various user inputs
-  se1 <- suppressWarnings(get_predicted_se(mod, vcov_estimation = "HC", vcov_type = "HC2"))
-  se2 <- get_predicted_se(mod, vcov = "HC2")
-  se3 <- get_predicted_se(mod, vcov = "vcovHC", vcov_args = list(type = "HC2"))
-  se4 <- get_predicted_se(mod, vcov = sandwich::vcovHC, vcov_args = list(type = "HC2"))
+  se1 <- suppressWarnings(insight:::get_predicted_se(mod, vcov_estimation = "HC", vcov_type = "HC2"))
+  se2 <- insight:::get_predicted_se(mod, vcov = "HC2")
+  se3 <- insight:::get_predicted_se(mod, vcov = "vcovHC", vcov_args = list(type = "HC2"))
+  se4 <- insight:::get_predicted_se(mod, vcov = sandwich::vcovHC, vcov_args = list(type = "HC2"))
   expect_true(all(se1 == se2))
   expect_true(all(se1 == se3))
   expect_true(all(se1 == se4))
-  se1 <- get_predicted_se(mod, vcov = "HC1")
-  se2 <- get_predicted_se(mod, vcov = sandwich::vcovHC, vcov_args = list(type = "HC1"))
+  se1 <- insight:::get_predicted_se(mod, vcov = "HC1")
+  se2 <- insight:::get_predicted_se(mod, vcov = sandwich::vcovHC, vcov_args = list(type = "HC1"))
   expect_true(all(se1 == se2))
 })
 
@@ -186,16 +189,16 @@ test_that("get_predicted - lmerMod", {
   x <- lme4::lmer(mpg ~ am + (1 | cyl), data = mtcars)
 
   # Link vs. relation
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
-  rezpred <- get_predicted(x, predict = "prediction")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
+  rezpred <- get_predicted(x, predict = "prediction", ci = .95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
   expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
   expect_true(all(summary(rezlink)$CI_high - summary(rezpred)$CI_high < 0))
 
   # Bootstrap
   set.seed(333)
-  rez <- as.data.frame(get_predicted(x, iterations = 5))
+  rez <- as.data.frame(get_predicted(x, iterations = 5, ci = .95))
   expect_equal(c(nrow(rez), ncol(rez)), c(32, 9))
 
 
@@ -211,7 +214,7 @@ test_that("get_predicted - lmerMod", {
   # expect_equal(mean(as.data.frame(rez)$CI_low - rez_emmeans$lower.PL), 0, tolerance = 0.5)
 
   # Compare with glmmTMB
-  ref <- insight::get_predicted(glmmTMB::glmmTMB(mpg ~ am + (1 | cyl), data = mtcars), predict = "expectation")
+  ref <- insight::get_predicted(glmmTMB::glmmTMB(mpg ~ am + (1 | cyl), data = mtcars), predict = "expectation", ci = .95)
   expect_equal(mean(abs(rezrela - ref)), 0, tolerance = 0.1) # A bit high
   # expect_equal(mean(abs(as.data.frame(rezrela)$SE - as.data.frame(ref)$SE)), 0, tolerance = 1e-5)
   # expect_equal(mean(abs(as.data.frame(rezrela)$CI_low - as.data.frame(ref)$CI_low)), 0, tolerance = 1e-5)
@@ -223,7 +226,7 @@ test_that("get_predicted - lmerMod", {
       refresh = 0, iter = 1000, seed = 333
     )
   )
-  rez_stan <- insight::get_predicted(xref, predict = "expectation")
+  rez_stan <- insight::get_predicted(xref, predict = "expectation", ci = .95)
   expect_equal(mean(abs(rezrela - rez_stan)), 0, tolerance = 0.1)
   # Different indeed
   # expect_equal(mean(as.data.frame(rezrela)$CI_low - as.data.frame(rez_stan)$CI_low), 0, tolerance = 0.5)
@@ -251,8 +254,8 @@ test_that("get_predicted - merMod", {
   skip_if_not_installed("lme4")
   skip_if_not_installed("glmmTMB")
   x <- lme4::glmer(vs ~ am + (1 | cyl), data = mtcars, family = "binomial")
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
   expect_true(min(rezlink) < 0)
   expect_true(min(rezrela) > 0)
   expect_true(min(summary(rezlink)$CI_low) < 0)
@@ -263,7 +266,7 @@ test_that("get_predicted - merMod", {
 
   # Compare with glmmTMB
   xref <- glmmTMB::glmmTMB(vs ~ am + (1 | cyl), data = mtcars, family = "binomial")
-  rez_ref <- insight::get_predicted(xref, predict = "expectation")
+  rez_ref <- insight::get_predicted(xref, predict = "expectation", ci = .95)
   expect_equal(max(abs(rezrela - rez_ref)), 0, tolerance = 1e-5)
   expect_equal(mean(abs(as.data.frame(rezrela)$SE - as.data.frame(rez_ref)$SE)), 0, tolerance = 0.2)
 })
@@ -274,20 +277,20 @@ test_that("get_predicted - glmmTMB", {
   x <- glmmTMB::glmmTMB(mpg ~ am + (1 | cyl), data = mtcars)
 
   # Link vs. relation
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
   expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
 
   # Bootstrap
   set.seed(333)
-  rez <- as.data.frame(get_predicted(x, iterations = 5, predict = "link"))
+  rez <- as.data.frame(get_predicted(x, iterations = 5, predict = "link", ci = .95))
   expect_equal(c(nrow(rez), ncol(rez)), c(32, 9))
 
   # Binomial
   x <- glmmTMB::glmmTMB(vs ~ am + (1 | cyl), data = mtcars, family = "binomial")
-  rezlink <- get_predicted(x, predict = "link")
-  rezrela <- get_predicted(x, predict = "expectation")
+  rezlink <- get_predicted(x, predict = "link", ci = .95)
+  rezrela <- get_predicted(x, predict = "expectation", ci = .95)
   expect_true(min(rezlink) < 0)
   expect_true(min(rezrela) > 0)
   expect_true(min(summary(rezlink)$CI_low) < 0)
@@ -297,7 +300,7 @@ test_that("get_predicted - glmmTMB", {
   expect_equal(nrow(as.data.frame(rez)), 32)
 
   # No random
-  rez <- insight::get_predicted(x, newdata = mtcars[c("am")], verbose = FALSE)
+  rez <- insight::get_predicted(x, newdata = mtcars[c("am")], verbose = FALSE, ci = .95)
   expect_true(!all(is.na(as.data.frame(rez))))
   x <- glmmTMB::glmmTMB(Petal.Length ~ Petal.Width + (1 | Species), data = iris)
   rez <- insight::get_predicted(x, data = data.frame(Petal.Width = c(0, 1, 2)), verbose = FALSE)
@@ -318,25 +321,25 @@ test_that("get_predicted - glmmTMB", {
 test_that("get_predicted - mgcv::gam and gamm", {
   skip_if_not_installed("mgcv")
   x <- mgcv::gam(mpg ~ am + s(wt), data = mtcars)
-  expect_equal(length(insight::get_predicted(x)), 32)
-  rez <- insight::get_predicted(x, data = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)))
+  expect_equal(length(insight::get_predicted(x, ci = .95)), 32)
+  rez <- insight::get_predicted(x, data = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)), ci = .95)
   expect_equal(length(rez), 3)
 
   # No smooth
-  rez <- insight::get_predicted(x, newdata = data.frame(am = c(0, 0, 1)))
+  rez <- insight::get_predicted(x, data = data.frame(am = c(0, 0, 1)), ci = .95)
   expect_equal(length(rez), 3)
-  rez2 <- insight::get_predicted(x, newdata = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)), include_smooth = FALSE)
+  rez2 <- insight::get_predicted(x, data = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)), ci = .95, include_smooth = FALSE)
   expect_equal(max(abs(as.numeric(rez - rez2))), 0, tolerance = 1e-4)
   expect_equal(length(unique(attributes(rez)$data$wt)), 1)
 
   # Bootstrap
   set.seed(333)
-  rez <- summary(get_predicted(x, iterations = 50))
+  rez <- summary(get_predicted(x, iterations = 50, ci = .95))
   expect_equal(nrow(rez), 32)
 
   # Binomial
   x <- mgcv::gam(vs ~ am + s(wt), data = mtcars, family = "binomial")
-  rez <- insight::get_predicted(x)
+  rez <- insight::get_predicted(x, ci = .95)
   expect_equal(length(rez), 32)
 
   expect_equal(max(abs(rez - stats::fitted(x))), 0)
@@ -345,7 +348,7 @@ test_that("get_predicted - mgcv::gam and gamm", {
 
   # GAMM
   x <- mgcv::gamm(vs ~ am + s(wt), random = list(cyl = ~1), data = mtcars, family = "binomial", verbosePQL = FALSE)
-  rez <- insight::get_predicted(x)
+  rez <- insight::get_predicted(x, ci = .95)
   expect_equal(length(rez), 32)
   expect_equal(max(abs(rez - x$gam$fitted.values)), 0)
   expect_equal(max(abs(rez - stats::predict(x$gam, type = "response"))), 0)
@@ -363,23 +366,23 @@ test_that("get_predicted - rstanarm", {
 
   # LM
   x <- rstanarm::stan_glm(mpg ~ cyl + hp, data = mtcars, refresh = 0, seed = 333)
-  rezlink <- summary(get_predicted(x, predict = "link"))
-  rezrela <- summary(get_predicted(x, predict = "expectation"))
+  rezlink <- summary(get_predicted(x, predict = "link", ci = .95))
+  rezrela <- summary(get_predicted(x, predict = "expectation", ci = .95))
   expect_equal(mean(abs(rezlink$Predicted - rezrela$Predicted)), 0, tolerance = 0.1)
   expect_equal(mean(abs(rezlink$CI_high - rezrela$CI_high)), 0, tolerance = 0.1)
-  rezpred <- summary(get_predicted(x, predict = "prediction"))
+  rezpred <- summary(get_predicted(x, predict = "prediction", ci = .95))
   expect_equal(mean(abs(rezlink$Predicted - rezpred$Predicted)), 0, tolerance = 0.1)
   expect_true(all(mean(rezlink$CI_high - rezpred$CI_high) < 0))
 
   # GLM
   x <- rstanarm::stan_glm(vs ~ wt, data = mtcars, family = "binomial", refresh = 0, seed = 333)
-  rezlink <- summary(get_predicted(x, predict = "link"))
-  rezrela <- summary(get_predicted(x, predict = "expectation"))
+  rezlink <- summary(get_predicted(x, predict = "link", ci = .95))
+  rezrela <- summary(get_predicted(x, predict = "expectation", ci = .95))
   expect_true(min(rezlink$Predicted) < 0)
   expect_true(min(rezrela$Predicted) > 0)
   expect_true(min(rezlink$CI_high) < 0)
   expect_true(min(rezrela$CI_high) > 0)
-  rezpred <- summary(get_predicted(x, predict = "prediction"))
+  rezpred <- summary(get_predicted(x, predict = "prediction", ci = .95))
   expect_equal(mean(abs(rezrela$Predicted - rezpred$Predicted)), 0, tolerance = 0.1)
   expect_true(all(mean(rezrela$CI_high - rezpred$CI_high) < 0))
 
@@ -390,13 +393,13 @@ test_that("get_predicted - rstanarm", {
       seed = 333, iter = 500
     )
   )
-  rezrela <- summary(get_predicted(x, predict = "expectation"))
-  rezpred <- summary(get_predicted(x, predict = "prediction"))
-  rezrela2 <- summary(get_predicted(x, predict = "expectation", include_random = FALSE))
-  rezpred2 <- summary(get_predicted(x, predict = "prediction", include_random = FALSE))
+  rezrela <- summary(get_predicted(x, predict = "expectation", ci = .95))
+  rezpred <- summary(get_predicted(x, predict = "prediction", ci = .95))
+  rezrela2 <- summary(get_predicted(x, predict = "expectation", ci = .95, include_random = FALSE))
+  rezpred2 <- summary(get_predicted(x, predict = "prediction", ci = .95, include_random = FALSE))
   expect_true(mean(abs(rezrela$Predicted - rezrela2$Predicted)) > 0)
   expect_true(mean(abs(rezpred$Predicted - rezpred2$Predicted)) > 0)
-  rezrela3 <- summary(get_predicted(x, predict = "expectation", data = mtcars["am"]), verbose = FALSE)
+  rezrela3 <- summary(get_predicted(x, predict = "expectation", ci = .95, data = mtcars["am"]), verbose = FALSE)
   expect_equal(mean(abs(rezrela2$Predicted - rezrela3$Predicted)), 0, tolerance = 0.001)
 })
 
@@ -437,9 +440,9 @@ test_that("get_predicted - FA / PCA", {
 test_that("lm: get_predicted vs barebones `predict()`", {
   mod <- lm(mpg ~ hp + factor(cyl), mtcars)
   known <- predict(mod, se.fit = TRUE, interval = "confidence")
-  unknown1 <- as.data.frame(get_predicted(mod))
-  unknown2 <- as.data.frame(get_predicted(mod, predict = "expectation"))
-  unknown3 <- suppressWarnings(as.data.frame(get_predicted(mod, predict = "response")))
+  unknown1 <- as.data.frame(get_predicted(mod, ci = .95))
+  unknown2 <- as.data.frame(get_predicted(mod, ci = .95, predict = "expectation"))
+  unknown3 <- suppressWarnings(as.data.frame(get_predicted(mod, ci = .95, predict = "response")))
   expect_equal(unknown1$Predicted, known$fit[, "fit"], ignore_attr = TRUE)
   expect_equal(unknown1$SE, known$se.fit, ignore_attr = TRUE)
   expect_equal(unknown1$CI_low, known$fit[, "lwr"], ignore_attr = TRUE)
@@ -471,16 +474,16 @@ test_that("`predict()` vs. `get_predicted` link equivalence", {
   # link
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
   known <- predict(mod, type = "link", interval = "confidence", se.fit = TRUE)
-  unknown <- as.data.frame(get_predicted(mod, predict = NULL, type = "link"))
+  unknown <- as.data.frame(get_predicted(mod, predict = NULL, type = "link", ci = .95))
   expect_equal(unname(known$fit), unknown$Predicted)
   expect_equal(unname(known$se.fit), unknown$SE)
 
   # response
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
   known <- predict(mod, type = "response", se.fit = TRUE)
-  unknown1 <- as.data.frame(get_predicted(mod, predict = "expectation"))
-  unknown2 <- as.data.frame(get_predicted(mod, predict = NULL, type = "response"))
-  unknown3 <- as.data.frame(get_predicted(mod, predict = "response"))
+  unknown1 <- as.data.frame(get_predicted(mod, predict = "expectation", ci = .95))
+  unknown2 <- as.data.frame(get_predicted(mod, predict = NULL, type = "response", ci = .95))
+  unknown3 <- as.data.frame(get_predicted(mod, predict = "response", ci = .95))
   expect_equal(unname(known$fit), unknown1$Predicted)
   expect_equal(unname(known$se.fit), unknown1$SE)
   expect_equal(unname(known$fit), unknown2$Predicted)
@@ -495,19 +498,19 @@ test_that("hurdle: get_predicted matches `predict()`", {
   data("bioChemists", package = "pscl")
   mod <- pscl::hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
   known <- predict(mod, type = "response")
-  unknown <- get_predicted(mod, predict = "response")
+  unknown <- get_predicted(mod, predict = "response", ci = .95)
   expect_equal(known, unknown, ignore_attr = TRUE)
   known <- predict(mod, type = "zero")
-  unknown <- get_predicted(mod, predict = "zero")
+  unknown <- get_predicted(mod, predict = "zero", ci = .95)
   expect_equal(known, unknown, ignore_attr = TRUE)
 })
 
 
 test_that("bugfix: used to return all zeros", {
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
-  pred <- get_predicted(mod, predict = "response")
+  pred <- get_predicted(mod, predict = "response", ci = .95)
   expect_false(any(pred == 0))
-  expect_error(expect_warning(get_predicted(mod, predict = "original")))
+  expect_error(expect_warning(get_predicted(mod, predict = "original", ci = .95)))
 })
 
 
@@ -521,9 +524,9 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
       chains = 2, iter = 1000, seed = 1024, silent = 2
     )
   )
-  x <- get_predicted(mod, predict = "link")
-  y <- get_predicted(mod, predict = "expectation")
-  z <- get_predicted(mod, predict = NULL, type = "response", verbose = FALSE)
+  x <- get_predicted(mod, predict = "link", ci = .95)
+  y <- get_predicted(mod, predict = "expectation", ci = .95)
+  z <- get_predicted(mod, predict = NULL, type = "response", ci = .95, verbose = FALSE)
   expect_equal(round(x[1], 1), -1.5, tolerance = 1e-1)
   expect_equal(round(y[1], 1), .2, tolerance = 1e-1)
   expect_equal(y, z, ignore_attr = TRUE)
@@ -540,7 +543,7 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
       family = categorical(link = "logit", refcat = "4")
     ))
   )
-  x <- as.data.frame(get_predicted(model))
+  x <- as.data.frame(get_predicted(model, ci = .95))
   # Test shape
   expect_equal(c(nrow(x), ncol(x)), c(32 * 3, 1006))
   # Test whether median point-estimate indeed different from default (mean)
