@@ -1,7 +1,9 @@
-.runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
-.runStanTest <- Sys.getenv("RunAllinsightStanTests") == "yes"
+skip_on_os(os = "mac")
 
-if (.runThisTest && .runStanTest && requiet("testthat") && requiet("insight") && requiet("brms")) {
+is_dev_version <- length(strsplit(packageDescription("insight")$Version, "\\.")[[1]]) > 3
+run_stan <- .Platform$OS.type == "unix" && is_dev_version
+
+if (run_stan && requiet("testthat") && requiet("insight") && requiet("brms")) {
   data(mtcars)
   set.seed(123)
 
