@@ -2,9 +2,9 @@
 .runStanTest <- Sys.getenv("RunAllinsightStanTests") == "yes"
 
 if (.runThisTest && .runStanTest &&
-  suppressWarnings(require("testthat") &&
-    require("insight") &&
-    require("rstanarm"))) {
+  suppressWarnings(requiet("testthat") &&
+    requiet("insight") &&
+    requiet("rstanarm"))) {
   data("pbcLong")
   m1 <- download_model("stanmvreg_1")
 
@@ -119,7 +119,7 @@ if (.runThisTest && .runStanTest &&
 
   test_that("find_paramaters", {
     expect_equal(
-      find_parameters(m1),
+      find_parameters(m1, component = "all"),
       structure(list(
         y1 = list(
           conditional = c("(Intercept)", "year"),
@@ -140,7 +140,26 @@ if (.runThisTest && .runStanTest &&
     )
 
     expect_equal(
-      find_parameters(m1, effects = "fixed"),
+      find_parameters(m1),
+      structure(list(
+        y1 = list(
+          conditional = c("(Intercept)", "year"),
+          random = sprintf("b[(Intercept) id:%i]", 1:40)
+        ),
+        y2 = list(
+          conditional = c("(Intercept)", "sexf", "year"),
+          random = sprintf(
+            c("b[(Intercept) id:%i]", "b[year id:%i]"),
+            rep(1:40, each = 2)
+          )
+        )
+      ),
+      is_mv = "1"
+      )
+    )
+
+    expect_equal(
+      find_parameters(m1, effects = "fixed", component = "all"),
       structure(list(
         y1 = list(
           conditional = c("(Intercept)", "year"),
@@ -155,6 +174,29 @@ if (.runThisTest && .runStanTest &&
       )
     )
 
+    expect_equal(
+      find_parameters(m1, effects = "fixed"),
+      structure(list(
+        y1 = list(conditional = c("(Intercept)", "year")),
+        y2 = list(conditional = c("(Intercept)", "sexf", "year"))
+      ),
+      is_mv = "1"
+      )
+    )
+
+    expect_equal(
+      find_parameters(m1, effects = "random", component = "all"),
+      structure(list(
+        y1 = list(random = sprintf("b[(Intercept) id:%i]", 1:40)),
+        y2 = list(random = sprintf(
+          c("b[(Intercept) id:%i]", "b[year id:%i]"),
+          rep(1:40, each = 2)
+        ))
+      ),
+      is_mv = "1"
+      )
+    )
+
     expect_equal(
       find_parameters(m1, effects = "random"),
       structure(list(
@@ -169,7 +211,7 @@ if (.runThisTest && .runStanTest &&
     )
   })
 
-  test_that("get_paramaters", {
+  test_that("get_parameters", {
     expect_equal(
       colnames(get_parameters(m1)),
       c(
