@@ -134,6 +134,10 @@ if (requiet("testthat") &&
     expect_true(inherits(p4, "factor"))
     expect_true(all(c("Row", "Response", "Predicted") %in% colnames(p1)))
     expect_true(all(c("Row", "Response", "Predicted") %in% colnames(p3)))
-  })
 
+    d <- get_datagrid(m1, at = "Type")
+    p1 <- get_predicted(m1, predict = "expectation", data = d)
+    expect_equal(colnames(p1), c("Row", "Type", "Response", "Predicted"))
+    expect_equal(dim(p1), c(12, 4))
+  })
 }
